bayespy.inference.vmp.nodes.poisson.PoissonDistribution.compute_fixed_moments_and_f
===================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.poisson

.. automethod:: PoissonDistribution.compute_fixed_moments_and_f